@@ -517,6 +517,7 @@ class SchemaDefBuild(object):
     # -------------------------- ------------- ------------- ------------- ------------- ------------- -------------
     def __getAmmendedAttributeFeatures(self, collectionName, catName, documentDefHelper):
         #
+        useDefaultBrief = False
         aD = self.__contentInfo.getAttributeFeatures(catName)
         for atName, fD in aD.items():
             ascL = documentDefHelper.getAttributeSearchContexts(collectionName, catName, atName)
@@ -528,6 +529,13 @@ class SchemaDefBuild(object):
             tS = documentDefHelper.getAttributeDescription(catName, atName, contextType="brief")
             if tS:
                 fD["DESCRIPTION_ANNOTATED"].append({"text": tS, "context": "brief"})
+            elif useDefaultBrief:
+                # Use content == deposition or then dictionary for 'brief' by default -
+                for tD in fD["DESCRIPTION_ANNOTATED"]:
+                    if tD["context"] == "deposition":
+                        fD["DESCRIPTION_ANNOTATED"].append({"text": tD["text"], "context": "brief"})
+                    elif tD["context"] == "dictionary":
+                        fD["DESCRIPTION_ANNOTATED"].append({"text": tD["text"], "context": "brief"})
         #
         return aD
         #
@@ -584,6 +592,7 @@ class SchemaDefBuild(object):
         exportSearchContext = False
         addRcsbExtensions = "rcsb" in enforceOpts
         addBlockAttribute = True
+        mandatorySubcategoryAttributes = True
         addPrimaryKey = "addPrimaryKey" in enforceOpts
         suppressSingleton = not documentDefHelper.getRetainSingletonObjects(collectionName)
         suppressRelations = documentDefHelper.getSuppressedCategoryRelationships(collectionName)
@@ -705,8 +714,13 @@ class SchemaDefBuild(object):
                     catPropD = {typeKey: "array", "items": pD, "minItems": 1, "uniqueItems": True}
                 #
                 if dataTypingU == "JSON" and addRcsbExtensions:
-                    isNested = documentDefHelper.isCategoryNested(collectionName, catName)
-                    catPropD["rcsb_nested_indexing"] = isNested
+                    if documentDefHelper.isCategoryNested(collectionName, catName):
+                        tD = documentDefHelper.getCategoryNestedContext(collectionName, catName)
+                        if "FIRST_CONTEXT_PATH" in tD and tD["FIRST_CONTEXT_PATH"]:
+                            catPropD["rcsb_nested_indexing"] = True
+                            catPropD["rcsb_nested_indexing_context"] = [{"category_name": tD["CONTEXT_NAME"], "category_path": tD["FIRST_CONTEXT_PATH"]}]
+                        else:
+                            catPropD["rcsb_nested_indexing"] = True
             if addBlockAttribute and blockAttributeName:
                 schemaAttributeName = convertNameF(blockAttributeName)
                 pD.setdefault("required", []).append(schemaAttributeName)
@@ -745,7 +759,9 @@ class SchemaDefBuild(object):
                         if removeSubCategoryPrefix:
                             schemaAttributeName = schemaAttributeName.replace(subCategory + "_", "")
                         #
-                        isRequired = "mandatoryAttributes" in enforceOpts and fD["IS_MANDATORY"]
+                        # isRequired = "mandatoryAttributes" in enforceOpts and fD["IS_MANDATORY"]
+                        # JDW separate general support for mandatory attributes and support in subcategories.
+                        isRequired = mandatorySubcategoryAttributes and fD["IS_MANDATORY"]
                         if isRequired:
                             reqL.append(schemaAttributeName)
                         #
@@ -762,8 +778,15 @@ class SchemaDefBuild(object):
                         else:
                             subCatPropD[subCategory] = {typeKey: "array", "items": scD, "uniqueItems": False}
                             if dataTypingU == "JSON" and addRcsbExtensions:
-                                isNested = documentDefHelper.isSubCategoryNested(collectionName, subCategory)
-                                subCatPropD[subCategory]["rcsb_nested_indexing"] = isNested
+                                if documentDefHelper.isSubCategoryNested(collectionName, catName, subCategory):
+                                    tD = documentDefHelper.getSubCategoryNestedContext(collectionName, catName, subCategory)
+                                    if "FIRST_CONTEXT_PATH" in tD:
+                                        catPropD["rcsb_nested_indexing"] = True
+                                        subCatPropD[subCategory]["rcsb_nested_indexing_context"] = [
+                                            {"category_name": tD["CONTEXT_NAME"], "category_path": tD["FIRST_CONTEXT_PATH"]}
+                                        ]
+                                    else:
+                                        subCatPropD[subCategory]["rcsb_nested_indexing"] = True
             #
             if subCatPropD:
                 logger.debug("%s %s %s processing subcategory properties %r", databaseName, collectionName, catName, subCatPropD.items())
