@@ -567,11 +567,16 @@ class DictMethodChemRefHelper(object):
             #
             # Create the new target category
             if not dataContainer.exists(catName):
-                dataContainer.append(DataCategory(catName, attributeNameList=["comp_id", "ordinal", "name", "provenance_code"]))
+                dataContainer.append(DataCategory(catName, attributeNameList=["comp_id", "ordinal", "name", "provenance_source"]))
             else:
                 # remove the rowlist -
                 pass
             #
+            pTupL = self.__dApi.getEnumListWithDetail(catName, "provenance_source")
+            provLookupD = {pTup[0].upper(): pTup[0] for pTup in pTupL}
+            provLookupD["ACD-LABS"] = "ACDLabs"
+            provLookupD["PDB"] = "PDB Reference Data"
+
             wObj = dataContainer.getObj(catName)
             #
             # Get all of the names relevant names from the definition -
@@ -588,26 +593,41 @@ class DictMethodChemRefHelper(object):
             wObj.setValue(ccId, "comp_id", iRow)
             wObj.setValue(ccName, "name", iRow)
             wObj.setValue(iRow + 1, "ordinal", iRow)
-            wObj.setValue(provCode, "provenance_code", iRow)
+            wObj.setValue(provCode, "provenance_source", iRow)
             iRow += 1
+            #
+            if dataContainer.exists("pdbx_chem_comp_synoynms"):
+                qObj = dataContainer.getObj("pdbx_chem_comp_synoynms")
+                for ii in range(qObj.getRowCount()):
+                    nm = qObj.getValue("name", ii)
+                    wObj.setValue(ccId, "comp_id", iRow)
+                    wObj.setValue(nm, "name", iRow)
+                    wObj.setValue(iRow + 1, "ordinal", iRow)
+                    wObj.setValue(provCode, "provenance_source", iRow)
+                    iRow += 1
+
             for nm in ccSynonymL:
                 if nm in ["?", "."]:
                     continue
                 wObj.setValue(ccId, "comp_id", iRow)
                 wObj.setValue(nm, "name", iRow)
                 wObj.setValue(iRow + 1, "ordinal", iRow)
-                wObj.setValue(provCode, "provenance_code", iRow)
+                wObj.setValue(provCode, "provenance_source", iRow)
                 iRow += 1
             #
             ccIObj = dataContainer.getObj("pdbx_chem_comp_identifier")
             for ii in range(ccIObj.getRowCount()):
                 nm = ccIObj.getValue("identifier", ii)
                 prog = ccIObj.getValue("program", ii)
-                wObj.setValue(ccId, "comp_id", iRow)
-                wObj.setValue(nm, "name", iRow)
-                wObj.setValue(iRow + 1, "ordinal", iRow)
-                wObj.setValue(prog, "provenance_code", iRow)
-                iRow += 1
+                if prog and prog.upper() in provLookupD:
+                    sProg = provLookupD[prog.upper()]
+                    wObj.setValue(ccId, "comp_id", iRow)
+                    wObj.setValue(nm, "name", iRow)
+                    wObj.setValue(iRow + 1, "ordinal", iRow)
+                    wObj.setValue(sProg, "provenance_source", iRow)
+                    iRow += 1
+                else:
+                    logger.error("%s unknown provenance %r", ccId, prog)
             #
             rP = kwargs.get("resourceProvider")
             dbProvider = rP.getResource("DrugBankProvider instance") if rP else None
@@ -621,7 +641,7 @@ class DictMethodChemRefHelper(object):
                         wObj.setValue(ccId, "comp_id", iRow)
                         wObj.setValue(nm, "name", iRow)
                         wObj.setValue(iRow + 1, "ordinal", iRow)
-                        wObj.setValue("DrugBank", "provenance_code", iRow)
+                        wObj.setValue("DrugBank", "provenance_source", iRow)
                         iRow += 1
 
             return True
