@@ -150,7 +150,7 @@ class DictMethodEntityHelper(object):
             #
             _rcsb_polymer_entity_align.reference_database_name
             _rcsb_polymer_entity_align.reference_database_accession
-            _rcsb_polymer_entity_align.provenance_code
+            _rcsb_polymer_entity_align.provenance_source
             #
             _rcsb_polymer_entity_align.aligned_regions_ref_beg_seq_id
             _rcsb_polymer_entity_align.aligned_regions_entity_beg_seq_id
@@ -176,7 +176,7 @@ class DictMethodEntityHelper(object):
             # ---
 
             iRow = cObj.getRowCount()
-            for (entryId, entityId, provCode), refD in pdbEntityAlignD.items():
+            for (entryId, entityId, provSource), refD in pdbEntityAlignD.items():
                 #
                 for (dbName, dbAcc, dbIsoform), saoL in refD.items():
                     #
@@ -193,7 +193,7 @@ class DictMethodEntityHelper(object):
                     cObj.setValue(dbAcc, "reference_database_accession", iRow)
                     if dbIsoform:
                         cObj.setValue(dbIsoform, "reference_database_isoform", iRow)
-                    cObj.setValue(provCode, "provenance_code", iRow)
+                    cObj.setValue(provSource, "provenance_source", iRow)
                     #
                     cObj.setValue(",".join([str(sao.getDbSeqIdBeg()) for sao in saoL]), "aligned_regions_ref_beg_seq_id", iRow)
                     cObj.setValue(",".join([str(sao.getEntitySeqIdBeg()) for sao in saoL]), "aligned_regions_entity_beg_seq_id", iRow)
@@ -302,6 +302,7 @@ class DictMethodEntityHelper(object):
                         dbIdL = []
                         for authAsymId in authAsymIdL:
                             dbIdL.extend(self.__ssP.getIdentifiers(entryId, authAsymId, idType="PFAMID"))
+                        # --- NO LONGER USING THIS CODE ---
                         for dbId in sorted(set(dbIdL)):
                             relatedAnnIdD["dbName"].append("Pfam")
                             relatedAnnIdD["provSource"].append("SIFTS")
@@ -367,10 +368,10 @@ class DictMethodEntityHelper(object):
                     cObj.setValue(",".join(refSeqIdD["provSource"]).strip(), "reference_sequence_identifiers_provenance_source", ii)
                     cObj.setValue(",".join(refSeqIdD["dbIsoform"]).strip(), "reference_sequence_identifiers_database_isoform", ii)
                 #
-                if relatedAnnIdD["dbName"]:
-                    cObj.setValue(",".join(relatedAnnIdD["dbName"]).strip(), "related_annotation_identifiers_resource_name", ii)
-                    cObj.setValue(",".join(relatedAnnIdD["dbAccession"]).strip(), "related_annotation_identifiers_resource_identifier", ii)
-                    cObj.setValue(",".join(relatedAnnIdD["provSource"]).strip(), "related_annotation_identifiers_provenance_source", ii)
+                # if relatedAnnIdD["dbName"]:
+                #    cObj.setValue(",".join(relatedAnnIdD["dbName"]).strip(), "related_annotation_identifiers_resource_name", ii)
+                #    cObj.setValue(",".join(relatedAnnIdD["dbAccession"]).strip(), "related_annotation_identifiers_resource_identifier", ii)
+                #    cObj.setValue(",".join(relatedAnnIdD["provSource"]).strip(), "related_annotation_identifiers_provenance_source", ii)
                 #
                 ii += 1
             _ = self.__addEntityCompIds(dataContainer)
@@ -403,7 +404,7 @@ class DictMethodEntityHelper(object):
             _rcsb_entity_source_organism.scientific_name
             _rcsb_entity_source_organism.common_name
             _rcsb_entity_source_organism.ncbi_taxonomy_id
-            _rcsb_entity_source_organism.provenance_code
+            _rcsb_entity_source_organism.provenance_source
             _rcsb_entity_source_organism.beg_seq_num
             _rcsb_entity_source_organism.end_seq_num
             _rcsb_entity_source_organism.taxonomy_lineage_id
@@ -419,7 +420,7 @@ class DictMethodEntityHelper(object):
             _rcsb_entity_host_organism.scientific_name
             _rcsb_entity_host_organism.common_name
             _rcsb_entity_host_organism.ncbi_taxonomy_id
-            _rcsb_entity_host_organism.provenance_code
+            _rcsb_entity_host_organism.provenance_source
             _rcsb_entity_host_organism.beg_seq_num
             _rcsb_entity_host_organism.end_seq_num
             _rcsb_entity_host_organism.taxonomy_lineage_id
@@ -508,7 +509,7 @@ class DictMethodEntityHelper(object):
             #
             eObj = dataContainer.getObj("entity")
             entityIdL = eObj.getAttributeValueList("id")
-            pCode = "PDB Primary Data"
+            provSource = "PDB Primary Data"
             #
             partCountD = {}
             srcL = []
@@ -572,12 +573,14 @@ class DictMethodEntityHelper(object):
                     tvL = [tv]
                 for v in tvL:
                     cObj.setValue(sType, "source_type", iRow)
-                    cObj.setValue(pCode, "provenance_code", iRow)
+                    cObj.setValue(provSource, "provenance_source", iRow)
                     for ii, at in enumerate(atL):
-                        if at in ["rcsb_gene_name_value"]:
+                        # add check for missing values here
+                        if at in ["rcsb_gene_name_value"] and v[ii] and v[ii] not in [".", "?"]:
                             tgL = v[ii].split(",")
-                            cObj.setValue(";".join(tgL), at, iRow)
-                            cObj.setValue(";".join([pCode for jj in range(len(tgL))]), "rcsb_gene_name_provenance_code", iRow)
+                            fgL = self.__filterCaseDuplicates(tgL)
+                            cObj.setValue(";".join(fgL), at, iRow)
+                            cObj.setValue(";".join([provSource for jj in range(len(tgL))]), "rcsb_gene_name_provenance_source", iRow)
                         else:
                             cObj.setValue(v[ii], at, iRow)
                         # if at == 'ncbi_taxonomy_id' and v[ii] and v[ii] not in ['.', '?'] and v[ii].isdigit():
@@ -597,7 +600,8 @@ class DictMethodEntityHelper(object):
                             #
                             cnL = taxU.getCommonNames(taxId)
                             if cnL:
-                                cObj.setValue(";".join(list(OrderedDict.fromkeys(cnL))), "ncbi_common_names", iRow)
+                                fcnL = self.__filterCaseDuplicates(cnL)
+                                cObj.setValue(";".join(list(OrderedDict.fromkeys(fcnL))), "ncbi_common_names", iRow)
                             # Add lineage -
                             linL = taxU.getLineageWithNames(taxId)
                             if linL is not None:
@@ -622,7 +626,7 @@ class DictMethodEntityHelper(object):
                 else:
                     tvL = [tv]
                 for v in tvL:
-                    hObj.setValue(pCode, "provenance_code", iRow)
+                    hObj.setValue(provSource, "provenance_source", iRow)
                     for ii, at in enumerate(atL):
                         hObj.setValue(v[ii], at, iRow)
                         #  if at == 'ncbi_taxonomy_id' and v[ii] and v[ii] not in ['.', '?'] and v[ii].isdigit():
@@ -1032,6 +1036,9 @@ class DictMethodEntityHelper(object):
                 "rcsb_macromolecular_names_combined_name",
                 "rcsb_macromolecular_names_combined_provenance_source",
                 "rcsb_macromolecular_names_combined_provenance_code",
+                "rcsb_enzyme_class_combined_ec",
+                "rcsb_enzyme_class_combined_provenance_source",
+                "rcsb_enzyme_class_combined_depth",
             ]
             for at in atList:
                 if not eObj.hasAttribute(at):
@@ -1047,6 +1054,12 @@ class DictMethodEntityHelper(object):
             ncObj = None
             if dataContainer.exists("entity_name_com"):
                 ncObj = dataContainer.getObj("entity_name_com")
+            # get an BIRD assigned names -
+            birdFeatureD = self.__getBirdFeatures(dataContainer)
+            birdNameD = {}
+            for (entityId, _, _, filteredFeature), fName in birdFeatureD.items():
+                if filteredFeature == "BIRD_MOLECULAR_NAME" and fName:
+                    birdNameD.setdefault(entityId, []).append(fName)
 
             for ii in range(eObj.getRowCount()):
                 entityId = eObj.getValue("id", ii)
@@ -1058,6 +1071,9 @@ class DictMethodEntityHelper(object):
                 eObj.setValue("?", "rcsb_macromolecular_names_combined_name", ii)
                 eObj.setValue("?", "rcsb_macromolecular_names_combined_provenance_source", ii)
                 eObj.setValue("?", "rcsb_macromolecular_names_combined_provenance_code", ii)
+                eObj.setValue("?", "rcsb_enzyme_class_combined_ec", ii)
+                eObj.setValue("?", "rcsb_enzyme_class_combined_provenance_source", ii)
+                eObj.setValue("?", "rcsb_enzyme_class_combined_depth", ii)
                 #
                 if entityType not in ["polymer", "branched"]:
                     continue
@@ -1070,7 +1086,11 @@ class DictMethodEntityHelper(object):
                 nmL = str(eObj.getValue("pdbx_description", ii)).split(",")
                 nmL = self.__cleanupCsv(nmL)
                 nmL = [tV.strip() for tV in nmL if len(tV) > 3]
+                nmLookUpD = {}
                 for nm in nmL:
+                    if nm.upper() in nmLookUpD:
+                        continue
+                    nmLookUpD[nm.upper()] = True
                     nameL.append(nm)
                     sourceL.append("PDB Preferred Name")
                     provCodeL.append("ECO:0000304")
@@ -1088,11 +1108,23 @@ class DictMethodEntityHelper(object):
                     ncL = self.__cleanupCsv(ncL)
                     ncL = [tV.strip() for tV in ncL if len(tV) > 3]
                     for nc in ncL:
+                        if nc.upper() in nmLookUpD:
+                            continue
+                        nmLookUpD[nc.upper()] = True
                         nameL.append(nc)
                         sourceL.append("PDB Synonym")
                         provCodeL.append("ECO:0000303")
                     logger.debug("%s ii %d ncL %r", dataContainer.getName(), ii, ncL)
                 #
+                if entityId in birdNameD:
+                    for nm in birdNameD[entityId]:
+                        if nm.upper() in nmLookUpD:
+                            continue
+                        nmLookUpD[nm.upper()] = True
+                        nameL.append(nm)
+                        sourceL.append("PDB BIRD Name")
+                        provCodeL.append("ECO:0000303")
+                #
                 if nameL:
                     eObj.setValue(";".join(nameL), "rcsb_macromolecular_names_combined_name", ii)
                     eObj.setValue(";".join(sourceL), "rcsb_macromolecular_names_combined_provenance_source", ii)
@@ -1101,6 +1133,7 @@ class DictMethodEntityHelper(object):
                 # --------------------------------------------------------------------------
                 linL = []
                 ecIdUpdL = []
+                ecDepthUpdL = []
                 ecV = eObj.getValueOrDefault("pdbx_ec", ii, defaultValue=None)
                 if ecV:
                     ecIdL = ecV.split(",") if ecV else []
@@ -1115,6 +1148,7 @@ class DictMethodEntityHelper(object):
                             if tL:
                                 linL.extend(tL)
                                 ecIdUpdL.append(ecId)
+                                ecDepthUpdL.append(str(ecId.count(".") + 1))
 
                     if linL:
                         eObj.setValue(";".join([str(tup[0]) for tup in linL]), "rcsb_ec_lineage_depth", ii)
@@ -1122,8 +1156,14 @@ class DictMethodEntityHelper(object):
                         eObj.setValue(";".join([tup[2] for tup in linL]), "rcsb_ec_lineage_name", ii)
                     if ecIdUpdL:
                         eObj.setValue(",".join(ecIdUpdL), "pdbx_ec", ii)
+                        eObj.setValue(";".join(ecIdUpdL), "rcsb_enzyme_class_combined_ec", ii)
+                        eObj.setValue(";".join(ecDepthUpdL), "rcsb_enzyme_class_combined_depth", ii)
+                        eObj.setValue(";".join(["PDB Primary Data" for _ in ecIdUpdL]), "rcsb_enzyme_class_combined_provenance_source", ii)
                     else:
                         eObj.setValue("?", "pdbx_ec", ii)
+                        eObj.setValue("?", "rcsb_enzyme_class_combined_ec", ii)
+                        eObj.setValue("?", "rcsb_enzyme_class_combined_provenance_source", ii)
+                        eObj.setValue("?", "rcsb_enzyme_class_combined_depth", ii)
                         if ecIdL:
                             logger.warning("%s non-existent EC class detected %r", dataContainer.getName(), ecV)
             return True
@@ -1143,6 +1183,20 @@ class DictMethodEntityHelper(object):
             pass
         return rL
 
+    def __filterCaseDuplicates(self, inpSL):
+        oL = []
+        try:
+            lookUpD = {}
+            for inpS in inpSL:
+                if inpS.upper() in lookUpD:
+                    continue
+                lookUpD[inpS.upper()] = True
+                oL.append(inpS)
+        except Exception:
+            return inpSL
+
+        return oL
+
     def __getAttribList(self, sObj, atTupL):
         atL = []
         atSL = []
@@ -1173,19 +1227,35 @@ class DictMethodEntityHelper(object):
         tL = list(OrderedDict.fromkeys(countL))
         if len(tL) == 1 and tL[0] == 1:
             return [colL]
+        #
+        orig = False
         # Report pathological cases ...
-        if (len(tL) > 2) or (tL[0] != 1 and len(tL) == 2):
-            logger.error("%s integrated source data inconsistent %r colL", entryId, colL)
-            return [colL]
+        if orig:
+            if (len(tL) > 2) or (tL[0] != 1 and len(tL) == 2):
+                logger.error("%s integrated source data inconsistent %r colL", entryId, colL)
+                return [colL]
         #
         # Expand the columns with uniform length
         #
-        icL = []
-        maxL = tL[1]
-        for tc in tcL:
-            if len(tc) == 1:
-                tc = tc * maxL
-            icL.append(tc)
+
+        if orig:
+            icL = []
+            maxL = tL[1]
+            for tc in tcL:
+                if len(tc) == 1:
+                    tc = tc * maxL
+                icL.append(tc)
+        else:
+            icL = []
+            maxL = tL[1]
+            for tc in tcL:
+                if len(tc) == 1:
+                    tc = tc * maxL
+                if len(tc) < maxL:
+                    for _ in range(maxL - len(tc)):
+                        tc.append("?")
+                icL.append(tc[:maxL])
+
         #
         logger.debug("%s icL %r", entryId, icL)
         # Convert back to a row list
@@ -1281,7 +1351,8 @@ class DictMethodEntityHelper(object):
                 prdId = pfObj.getValue("prd_id", ii)
                 prdType = pfObj.getValueOrDefault("class", ii, defaultValue=None)
                 prdClass = pfObj.getValueOrDefault("type", ii, defaultValue=None)
-                pfD[prdId] = (prdType, prdClass)
+                prdName = pfObj.getValueOrDefault("name", ii, defaultValue=None)
+                pfD[prdId] = (prdType, prdClass, prdName)
 
             pObj = dataContainer.getObj("pdbx_molecule")
             bD = {}
@@ -1294,13 +1365,27 @@ class DictMethodEntityHelper(object):
                     bD[(entityId, compId, prdId, "BIRD_MOLECULE_TYPE")] = pfD[prdId][0]
                 if pfD[prdId][1]:
                     bD[(entityId, compId, prdId, "BIRD_MOLECULE_CLASS")] = pfD[prdId][1]
+                if pfD[prdId][2]:
+                    bD[(entityId, compId, prdId, "BIRD_MOLECULE_NAME")] = pfD[prdId][2]
 
         except Exception as e:
             logger.exception("Failing for %s with %s", dataContainer.getName(), str(e))
         return bD
 
+    def __getEntityFeatureTypes(self, eType):
+        eTupL = []
+        if eType == "polymer":
+            eTupL = self.__dApi.getEnumListWithDetail("rcsb_polymer_entity_feature_summary", "type")
+        elif eType == "non-polymer":
+            eTupL = self.__dApi.getEnumListWithDetail("rcsb_nonpolymer_entity_feature_summary", "type")
+        elif eType == "branched":
+            eTupL = self.__dApi.getEnumListWithDetail("rcsb_branched_entity_feature_summary", "type")
+        #
+        fTypeL = sorted([tup[0] for tup in eTupL])
+        return fTypeL
+
     def buildEntityFeatureSummary(self, dataContainer, catName, **kwargs):
-        """ Build category rcsb_entity_feature_summary
+        """ Build category rcsb_entity_feature_summary (UPDATED)
 
         Example:
 
@@ -1330,41 +1415,59 @@ class DictMethodEntityHelper(object):
             fObj = dataContainer.getObj("rcsb_entity_feature")
             #
             entityPolymerLengthD = self.__commonU.getPolymerEntityLengthsEnumerated(dataContainer)
+            eTypeD = self.__commonU.getEntityTypes(dataContainer)
 
             fCountD = OrderedDict()
             fMonomerCountD = OrderedDict()
             for ii in range(fObj.getRowCount()):
                 entityId = fObj.getValue("entity_id", ii)
+                #
                 fType = fObj.getValue("type", ii)
                 fId = fObj.getValue("feature_id", ii)
                 fCountD.setdefault(entityId, {}).setdefault(fType, set()).add(fId)
+
                 #
-                tS = fObj.getValueOrDefault("feature_ranges_beg_seq_id", ii, defaultValue=None)
-                if fObj.hasAttribute("feature_ranges_beg_seq_id") and tS is not None:
-                    begSeqIdL = str(fObj.getValue("feature_ranges_beg_seq_id", ii)).split(";")
-                    endSeqIdL = str(fObj.getValue("feature_ranges_end_seq_id", ii)).split(";")
+                tbegS = fObj.getValueOrDefault("feature_positions_beg_seq_id", ii, defaultValue=None)
+                tendS = fObj.getValueOrDefault("feature_positions_end_seq_id", ii, defaultValue=None)
+                if fObj.hasAttribute("feature_positions_beg_seq_id") and tbegS is not None and fObj.hasAttribute("feature_positions_end_seq_id") and tendS is not None:
+                    begSeqIdL = str(fObj.getValue("feature_positions_beg_seq_id", ii)).split(";")
+                    endSeqIdL = str(fObj.getValue("feature_positions_end_seq_id", ii)).split(";")
                     monCount = 0
                     for begSeqId, endSeqId in zip(begSeqIdL, endSeqIdL):
                         monCount += abs(int(endSeqId) - int(begSeqId) + 1)
                     fMonomerCountD.setdefault(entityId, {}).setdefault(fType, []).append(monCount)
-
-                tS = fObj.getValueOrDefault("feature_positions_seq_id", ii, defaultValue=None)
-                if fObj.hasAttribute("feature_positions_seq_id") and tS is not None:
-                    seqIdL = str(fObj.getValue("feature_positions_seq_id", ii)).split(";")
+                elif fObj.hasAttribute("feature_positions_beg_seq_id") and tbegS:
+                    seqIdL = str(fObj.getValue("feature_positions_beg_seq_id", ii)).split(";")
                     fMonomerCountD.setdefault(entityId, {}).setdefault(fType, []).append(len(seqIdL))
             #
             ii = 0
-            for entityId, fTypeD in fCountD.items():
-                for fType, fS in fTypeD.items():
+            for entityId, eType in eTypeD.items():
+                fTypes = self.__getEntityFeatureTypes(eType)
+                for fType in fTypes:
                     sObj.setValue(ii + 1, "ordinal", ii)
                     sObj.setValue(entryId, "entry_id", ii)
                     sObj.setValue(entityId, "entity_id", ii)
                     sObj.setValue(fType, "type", ii)
-                    sObj.setValue(len(fS), "count", ii)
+
+                    minL = maxL = None
                     fracC = 0.0
+                    fCount = 0
+                    if entityId in fCountD and fType in fCountD[entityId]:
+                        fCount = len(fCountD[entityId][fType])
+
                     if entityId in fMonomerCountD and fType in fMonomerCountD[entityId] and entityId in entityPolymerLengthD:
                         fracC = float(sum(fMonomerCountD[entityId][fType])) / float(entityPolymerLengthD[entityId])
+                    #
+                    if fType in ["artifact"] and entityId in fMonomerCountD and fType in fMonomerCountD[entityId]:
+                        minL = min(fMonomerCountD[entityId][fType])
+                        maxL = max(fMonomerCountD[entityId][fType])
+
                     sObj.setValue(round(fracC, 5), "coverage", ii)
+                    sObj.setValue(fCount, "count", ii)
+                    if minL is not None:
+                        sObj.setValue(minL, "minimum_length", ii)
+                        sObj.setValue(maxL, "maximum_length", ii)
+                    #
                     ii += 1
         except Exception as e:
             logger.exception("Failing with %s", str(e))
@@ -1382,20 +1485,13 @@ class DictMethodEntityHelper(object):
             _rcsb_entity_feature.type
             _rcsb_entity_feature.name
             _rcsb_entity_feature.description
-            _rcsb_entity_feature.feature_class_lineage_id
-            _rcsb_entity_feature.feature_class_lineage_name
-            _rcsb_entity_feature.feature_class_lineage_depth
             _rcsb_entity_feature.reference_scheme
-            _rcsb_entity_feature.provenance_code
+            _rcsb_entity_feature.provenance_source
             _rcsb_entity_feature.assignment_version
-            _rcsb_entity_feature.feature_ranges_beg_seq_id
-            _rcsb_entity_feature.feature_ranges_end_seq_id
-            _rcsb_entity_feature.feature_ranges_value
-            _rcsb_entity_feature.feature_positions_comp_id
-            _rcsb_entity_feature.feature_positions_seq_id
+            _rcsb_entity_feature.feature_positions_beg_seq_id
+            _rcsb_entity_feature.feature_positions_end_seq_id
             _rcsb_entity_feature.feature_positions_value
 
-
         """
         logger.debug("Starting with %r %r %r", dataContainer.getName(), catName, kwargs)
         try:
@@ -1430,7 +1526,7 @@ class DictMethodEntityHelper(object):
                 details = "Ligand targeted in this investigation"
                 cObj.setValue(details, "description", ii)
                 cObj.setValue(compId, "name", ii)
-                cObj.setValue("PDB", "provenance_code", ii)
+                cObj.setValue("PDB", "provenance_source", ii)
                 cObj.setValue("V1.0", "assignment_version", ii)
                 #
                 jj += 1
@@ -1452,13 +1548,12 @@ class DictMethodEntityHelper(object):
                 cObj.setValue(details, "description", ii)
                 #
                 cObj.setValue(fName, "name", ii)
-                cObj.setValue("PDB", "provenance_code", ii)
+                cObj.setValue("PDB", "provenance_source", ii)
                 cObj.setValue("V1.0", "assignment_version", ii)
                 #
                 jj += 1
                 ii += 1
             #
-
             # Monomer modifications
             jj = 1
             modMonomerFeatures = self.__commonU.getPolymerModifiedMonomerFeatures(dataContainer)
@@ -1474,16 +1569,17 @@ class DictMethodEntityHelper(object):
                     details = "Parent monomer %s" % parentCompId
                     cObj.setValue(details, "name", ii)
                 #
-                cObj.setValue(compId, "feature_positions_comp_id", ii)
-                cObj.setValue(seqId, "feature_positions_seq_id", ii)
+                cObj.setValue(compId, "feature_positions_beg_comp_id", ii)
+                cObj.setValue(seqId, "feature_positions_beg_seq_id", ii)
                 #
                 cObj.setValue("PDB entity", "reference_scheme", ii)
-                cObj.setValue("PDB", "provenance_code", ii)
+                cObj.setValue("PDB", "provenance_source", ii)
                 cObj.setValue("V1.0", "assignment_version", ii)
                 #
                 jj += 1
                 ii += 1
             #
+            #
             seqMonomerFeatures = self.__commonU.getEntitySequenceMonomerFeatures(dataContainer)
             for (entityId, seqId, compId, filteredFeature), sDetails in seqMonomerFeatures.items():
                 if filteredFeature not in ["mutation"]:
@@ -1496,11 +1592,11 @@ class DictMethodEntityHelper(object):
                 details = ",".join(list(sDetails))
                 cObj.setValue(details, "name", ii)
                 #
-                cObj.setValue(compId, "feature_positions_comp_id", ii)
-                cObj.setValue(seqId, "feature_positions_seq_id", ii)
+                cObj.setValue(compId, "feature_positions_beg_comp_id", ii)
+                cObj.setValue(seqId, "feature_positions_beg_seq_id", ii)
                 #
                 cObj.setValue("PDB entity", "reference_scheme", ii)
-                cObj.setValue("PDB", "provenance_code", ii)
+                cObj.setValue("PDB", "provenance_source", ii)
                 cObj.setValue("V1.0", "assignment_version", ii)
                 #
                 jj += 1
@@ -1519,11 +1615,11 @@ class DictMethodEntityHelper(object):
                 details = ",".join(list(sDetails))
                 cObj.setValue(details, "name", ii)
                 #
-                cObj.setValue(begSeqId, "feature_ranges_beg_seq_id", ii)
-                cObj.setValue(endSeqId, "feature_ranges_end_seq_id", ii)
+                cObj.setValue(begSeqId, "feature_positions_beg_seq_id", ii)
+                cObj.setValue(endSeqId, "feature_positions_end_seq_id", ii)
                 #
                 cObj.setValue("PDB entity", "reference_scheme", ii)
-                cObj.setValue("PDB", "provenance_code", ii)
+                cObj.setValue("PDB", "provenance_source", ii)
                 cObj.setValue("V1.0", "assignment_version", ii)
                 #
                 jj += 1
@@ -1533,101 +1629,6 @@ class DictMethodEntityHelper(object):
             logger.exception("%s %s failing with %s", dataContainer.getName(), catName, str(e))
         return False
 
-    def addTypedEntityCategoriesX(self, dataContainer, catName, **kwargs):
-        """ Slice common entity categories into type specific entity categories.
-
-        Args:
-            dataContainer (object): mmif.api.DataContainer object instance
-            catName (str): Category name
-
-        Returns:
-            bool: True for success or False otherwise
-
-        """
-        logger.debug("Starting with %r %r %r", dataContainer.getName(), catName, kwargs)
-        try:
-            if not (dataContainer.exists("entry") and dataContainer.exists("entity")):
-                return False
-            #  .... Do only once!
-            if dataContainer.exists("rcsb_polymer_entity") or dataContainer.exists("rcsb_nonpolymer_entity") or dataContainer.exists("rcsb_branched_entity"):
-                return True
-            # -----
-            eObj = dataContainer.getObj("entity")
-            eCount = eObj.getRowCount()
-            eTypeD = {eObj.getValue("id", ii): eObj.getValue("type", ii) for ii in range(eCount) if eObj.getValue("type", ii)}
-            eTypes = list(set(eTypeD.values()))
-            logger.info("%s entity types %r map %r", dataContainer.getName(), eTypes, eTypeD)
-            catTupD = {
-                "polymer": [
-                    ("entity", "rcsb_polymer_entity", "id"),
-                    ("entity_keywords", "rcsb_polymer_entity_keywords", "entity_id"),
-                    ("entity_name_com", "rcsb_polymer_entity_name_com", "entity_id"),
-                    ("entity_name_sys", "rcsb_polymer_entity_name_sys", "entity_id"),
-                    ("rcsb_entity_container_identifiers", "rcsb_polymer_entity_container_identifiers", "entity_id"),
-                    ("rcsb_entity_feature", "rcsb_polymer_entity_feature", "entity_id"),
-                    ("rcsb_entity_feature_summary", "rcsb_polymer_entity_feature_summary", "entity_id"),
-                ],
-                "non-polymer": [
-                    ("entity", "rcsb_nonpolymer_entity", "id"),
-                    ("entity_keywords", "rcsb_nonpolymer_entity_keywords", "entity_id"),
-                    ("entity_name_com", "rcsb_nonpolymer_entity_name_com", "entity_id"),
-                    ("entity_name_sys", "rcsb_nonpolymer_entity_name_sys", "entity_id"),
-                    ("rcsb_entity_container_identifiers", "rcsb_nonpolymer_entity_container_identifiers", "entity_id"),
-                    ("rcsb_entity_feature", "rcsb_nonpolymer_entity_feature", "entity_id"),
-                    ("rcsb_entity_feature_summary", "rcsb_nonpolymer_entity_feature_summary", "entity_id"),
-                ],
-                "branched": [
-                    ("entity", "rcsb_branched_entity", "id"),
-                    ("entity_keywords", "rcsb_branched_entity_keywords", "entity_id"),
-                    ("entity_name_com", "rcsb_branched_entity_name_com", "entity_id"),
-                    ("entity_name_sys", "rcsb_branched_entity_name_sys", "entity_id"),
-                    ("rcsb_entity_container_identifiers", "rcsb_branched_entity_container_identifiers", "entity_id"),
-                    ("rcsb_entity_feature", "rcsb_branched_entity_feature", "entity_id"),
-                    ("rcsb_entity_feature_summary", "rcsb_branched_entity_feature_summary", "entity_id"),
-                ],
-            }
-            for eType, catTupL in catTupD.items():
-                if eType in eTypes:
-                    # create new categories as needed
-                    for srcCatN, dstCatN, entityIdKey in catTupL:
-                        if dataContainer.exists(srcCatN):
-                            if not dataContainer.exists(dstCatN):
-                                dataContainer.append(DataCategory(dstCatN, attributeNameList=self.__dApi.getAttributeNameList(dstCatN)))
-                            srcObj = dataContainer.getObj(srcCatN)
-                            dstObj = dataContainer.getObj(dstCatN)
-                            jj = dstObj.getRowCount()
-                            for ii in range(srcObj.getRowCount()):
-                                entityId = srcObj.getValue(entityIdKey, ii)
-                                logger.info("%s srcCatN %s row %d key %r entityId %r", dataContainer.getName(), srcCatN, ii, entityIdKey, entityId)
-                                if eTypeD[entityId] != eType:
-                                    continue
-                                for dstAtName in dstObj.getAttributeList():
-                                    srcAtName = entityIdKey if dstAtName == "entity_id" else dstAtName
-                                    logger.debug(
-                                        "%s entityId %r srcCatN %r srcAtName %s dstCatN %s dstAtName %s", dataContainer.getName(), entityId, srcCatN, srcAtName, dstCatN, dstAtName
-                                    )
-                                    if srcObj.hasAttribute(srcAtName):
-                                        tS = srcObj.getValue(srcAtName, ii)
-                                        logger.debug("%s entityId %r srcCatN %r srcAtName %s value %s", dataContainer.getName(), entityId, srcCatN, srcAtName, tS)
-                                        if srcAtName in ["formula_weight"]:
-                                            # dalton to kiloDalton
-                                            try:
-                                                tV = float(tS) / 1000.0
-                                                tS = "%f.3" % tV
-                                            except Exception:
-                                                tS = "?"
-                                        if dstAtName in ["ordinal"]:
-                                            tS = jj + 1
-                                        _ = dstObj.setValue(tS, dstAtName, jj)
-                                    else:
-                                        logger.info("Missing srcCatN %s srcAtName %s", srcCatN, srcAtName)
-                                        _ = dstObj.setValue("?", dstAtName, jj)
-                                jj += 1
-            return True
-        except Exception as e:
-            logger.exception("%s for %s failing with %s", dataContainer.getName(), catName, str(e))
-        return False
-
     def addTypedEntityCategories(self, dataContainer, blockName, **kwargs):
         """ Slice common entity categories into type specific entity categories.
 
@@ -1709,6 +1710,8 @@ class DictMethodEntityHelper(object):
                     ("rcsb_entity_instance_validation_feature", "rcsb_polymer_instance_feature", "entity_id"),
                     ("rcsb_entity_instance_validation_feature_summary", "rcsb_polymer_instance_feature_summary", "entity_id"),
                     ("rcsb_struct_conn", "rcsb_polymer_struct_conn", "entity_id"),
+                    ("rcsb_entity_annotation", "rcsb_polymer_entity_annotation", "entity_id"),
+                    ("rcsb_entity_instance_annotation", "rcsb_polymer_instance_annotation", "entity_id"),
                 ],
                 "non-polymer": [
                     ("rcsb_entity_feature", "rcsb_nonpolymer_entity_feature", "entity_id"),
@@ -1718,6 +1721,8 @@ class DictMethodEntityHelper(object):
                     ("rcsb_entity_instance_validation_feature", "rcsb_nonpolymer_instance_feature", "entity_id"),
                     ("rcsb_entity_instance_validation_feature_summary", "rcsb_nonpolymer_instance_feature_summary", "entity_id"),
                     ("rcsb_struct_conn", "rcsb_nonpolymer_struct_conn", "entity_id"),
+                    ("rcsb_entity_annotation", "rcsb_nonpolymer_entity_annotation", "entity_id"),
+                    ("rcsb_entity_instance_annotation", "rcsb_nonpolymer_instance_annotation", "entity_id"),
                 ],
                 "branched": [
                     ("rcsb_entity_feature", "rcsb_branched_entity_feature", "entity_id"),
@@ -1727,6 +1732,8 @@ class DictMethodEntityHelper(object):
                     ("rcsb_entity_instance_validation_feature", "rcsb_branched_instance_feature", "entity_id"),
                     ("rcsb_entity_instance_validation_feature_summary", "rcsb_branched_instance_feature_summary", "entity_id"),
                     ("rcsb_struct_conn", "rcsb_branched _struct_conn", "entity_id"),
+                    ("rcsb_entity_annotation", "rcsb_branched_entity_annotation", "entity_id"),
+                    ("rcsb_entity_instance_annotation", "rcsb_branched_instance_annotation", "entity_id"),
                 ],
             }
             ok = self.__sliceCategoriesByEntityType(dataContainer, categoryMapD)
@@ -1796,3 +1803,89 @@ class DictMethodEntityHelper(object):
         except Exception as e:
             logger.exception("%s failing with %s", dataContainer.getName(), str(e))
         return False
+
+    #
+    def buildEntityAnnotations(self, dataContainer, catName, **kwargs):
+        """ Build category rcsb_entity_annotation ...
+
+        Example:
+            loop_
+            _rcsb_entity_annotation.ordinal
+            _rcsb_entity_annotation.entry_id
+            _rcsb_entity_annotation.entity_id
+            _rcsb_entity_annotation.annotation_id
+            _rcsb_entity_annotation.type
+            _rcsb_entity_annotation.name
+            _rcsb_entity_annotation.description
+            _rcsb_entity_annotation.annotation_lineage_id
+            _rcsb_entity_annotation.annotation_lineage_name
+            _rcsb_entity_annotation.annotation_lineage_depth
+            _rcsb_entity_annotation.provenance_source
+            _rcsb_entity_annotation.assignment_version
+
+        """
+        logger.debug("Starting with %r %r %r", dataContainer.getName(), catName, kwargs)
+        try:
+            if catName != "rcsb_entity_annotation":
+                return False
+            # Exit if source categories are missing
+            if not dataContainer.exists("entry"):
+                return False
+            #
+            # Create the new target category
+            if not dataContainer.exists(catName):
+                dataContainer.append(DataCategory(catName, attributeNameList=self.__dApi.getAttributeNameList(catName)))
+            cObj = dataContainer.getObj(catName)
+            #
+            eObj = dataContainer.getObj("entry")
+            entryId = eObj.getValue("id", 0)
+            #
+            # ---------------
+            ii = cObj.getRowCount()
+            jj = 1
+            #
+            targetFeatureD = self.__getTargetComponentFeatures(dataContainer)
+            #
+            for (entityId, compId, filteredFeature) in targetFeatureD:
+                cObj.setValue(ii + 1, "ordinal", ii)
+                cObj.setValue(entryId, "entry_id", ii)
+                cObj.setValue(entityId, "entity_id", ii)
+                cObj.setValue(compId, "comp_id", ii)
+                cObj.setValue(filteredFeature, "type", ii)
+                cObj.setValue("entity_annotation_%d" % jj, "annotation_id", ii)
+                details = "Ligand targeted in this investigation"
+                cObj.setValue(details, "description", ii)
+                cObj.setValue(compId, "name", ii)
+                cObj.setValue("PDB", "provenance_source", ii)
+                cObj.setValue("V1.0", "assignment_version", ii)
+                #
+                jj += 1
+                ii += 1
+            #
+            skipBird = True
+            if not skipBird:
+                # BIRD type and class
+                birdFeatureD = self.__getBirdFeatures(dataContainer)
+                for (entityId, compId, prdId, filteredFeature), fName in birdFeatureD.items():
+                    cObj.setValue(ii + 1, "ordinal", ii)
+                    cObj.setValue(entryId, "entry_id", ii)
+                    cObj.setValue(entityId, "entity_id", ii)
+                    cObj.setValue(compId, "comp_id", ii)
+                    cObj.setValue(filteredFeature, "type", ii)
+                    cObj.setValue("entity_annotation_%d" % jj, "annotation_id", ii)
+                    if compId:
+                        details = "Non-polymer BIRD %s chemical component %s" % (prdId, compId)
+                    else:
+                        details = "Polymer BIRD %s entity %s" % (prdId, entityId)
+                    cObj.setValue(details, "description", ii)
+                    #
+                    cObj.setValue(fName, "name", ii)
+                    cObj.setValue("PDB", "provenance_source", ii)
+                    cObj.setValue("V1.0", "assignment_version", ii)
+                    #
+                    jj += 1
+                    ii += 1
+            return True
+        except Exception as e:
+            logger.exception("%s %s failing with %s", dataContainer.getName(), catName, str(e))
+        return False
