@@ -64,6 +64,7 @@ __author__ = "John Westbrook"
 __email__ = "jwest@rcsb.rutgers.edu"
 __license__ = "Apache 2.0"
 
+# pylint: disable=too-many-lines
 
 import logging
 from string import capwords
@@ -346,6 +347,37 @@ class DictMethodEntryHelper(object):
 
         return revAbbrev
 
+    def assignPrimaryCitation(self, dataContainer, catName, atName, **kwargs):
+        """Normalize citation journal abbrev.
+
+        Args:
+            dataContainer (object): mmif.api.DataContainer object instance
+            catName (str): Category name
+            atName (str): Attribute name
+
+        Returns:
+            bool: True for success or False otherwise
+        """
+        logger.debug("Starting catName %s atName %s kwargs %r", catName, atName, kwargs)
+        try:
+            if not dataContainer.exists(catName):
+                return False
+            #
+            cObj = dataContainer.getObj(catName)
+            if not cObj.hasAttribute(atName):
+                cObj.appendAttribute(atName)
+            #
+            for ii in range(cObj.getRowCount()):
+                citId = cObj.getValue("id", ii)
+                if citId.upper() == "PRIMARY":
+                    cObj.setValue("Y", atName, ii)
+                else:
+                    cObj.setValue("N", atName, ii)
+            return True
+        except Exception as e:
+            logger.exception("Failing for %r with %s", dataContainer.getName(), str(e))
+        return False
+
     def __getEmdbIdentifiers(self, dataContainer):
         """[summary]
 
@@ -464,7 +496,11 @@ class DictMethodEntryHelper(object):
             cObj.setValue(tV, "emdb_ids", 0)
             tV = ",".join([tId for tId in emdbIdAltD]) if emdbIdAltD else "?"
             cObj.setValue(tV, "related_emdb_ids", 0)
-
+            #
+            modelIdList = self.__commonU.getModelIdList(dataContainer)
+            tV = ",".join([str(tId) for tId in modelIdList]) if modelIdList else "?"
+            cObj.setValue(tV, "model_ids", 0)
+            #
             return True
         except Exception as e:
             logger.exception("For %s failing with %s", catName, str(e))
@@ -637,6 +673,8 @@ class DictMethodEntryHelper(object):
                 swObj = dataContainer.getObj("em_software")
                 swNameL.extend(swObj.getAttributeUniqueValueList("name"))
             if swNameL:
+                swNameD = {swName.upper().strip(): True for swName in swNameL if swName not in [".", "?"]}
+                swNameL = sorted(swNameD.keys())
                 cObj.setValue(";".join(swNameL), "software_programs_combined", 0)
             # ---------------------------------------------------------------------------------------------------------
             #  ENTITY FEATURES
@@ -935,3 +973,37 @@ class DictMethodEntryHelper(object):
                     if self.__commonU.isFloat(rv):
                         rL.append(rv)
         return rL
+
+    def addCategoryPrimaryCitation(self, dataContainer, blockName, **kwargs):
+        """
+        Add  rcsb_primary_citation category as a copy or the citation category
+        with rcsb extensions.
+        """
+        try:
+            logger.debug("Starting with %r %r %r", dataContainer.getName(), blockName, kwargs)
+            # Exit if source categories are missing
+            if not dataContainer.exists("citation"):
+                return False
+            cObj = dataContainer.getObj("citation")
+            catName = "rcsb_primary_citation"
+            #
+            # Create the new target category rcsb_entry_info
+            if not dataContainer.exists(catName):
+                dataContainer.append(DataCategory(catName, attributeNameList=self.__dApi.getAttributeNameList(catName)))
+            # --------------------------------------------------------------------------------------------------------
+            # catName = rcsb_entry_info
+            rObj = dataContainer.getObj(catName)
+            atNameList = self.__dApi.getAttributeNameList(catName)
+            logger.debug("Category %s dict attributes %r", catName, atNameList)
+            #
+            for ii in range(cObj.getRowCount()):
+                pv = cObj.getValue("id", ii)
+                if pv.upper() == "PRIMARY":
+                    for atName in atNameList:
+                        if cObj.hasAttribute(atName):
+                            rObj.setValue(cObj.getValue(atName, ii), atName, 0)
+
+            return True
+        except Exception as e:
+            logger.exception("%s %s failing with %s", dataContainer.getName(), catName, str(e))
+        return False
