@@ -11,6 +11,7 @@
 #  13-Aug-2019 jdw return class instances in all cases. Add cache management support.
 #   9-Sep-2019 jdw add AtcProvider() and SiftsSummaryProvider()
 #  25-Nov-2019 jdw add CitationReferenceProvider(), ChemCompProvider() and  JournalTitleAbbreviationProvider()'s
+#  16-Feb-2020 jdw add support for configuration of development resources
 ##
 """
 Resource provider for DictMethodHelper tools.
@@ -139,12 +140,20 @@ class DictMethodResourceProvider(SingletonClass):
             bool: True for success or False otherwise
         """
         ret = True
+        tName = "CHECKING" if useCache else "REBUILDING"
+        logger.info("Begin %s cache for %d resources", tName, len(self.__resourcesD))
+        #
         for resourceName in self.__resourcesD:
-            logger.info("Caching resources for %r", resourceName)
+            logger.debug("Caching resources for %r", resourceName)
             tU = self.__resourcesD[resourceName](self.__cfgOb, self.__configName, self.__cachePath, useCache=useCache, **kwargs)
             ok = tU.testCache()
+            if not ok:
+                logger.error("%s %s fails", tName, resourceName)
             ret = ret and ok
-            logger.info("After %r status %r of %r", resourceName, ok, ret)
+            if not ret:
+                logger.info("%s resource %r step status %r cumulative status %r", tName, resourceName, ok, ret)
+        #
+        logger.info("Completed %s %d resources with status %r", tName, len(self.__resourcesD), ret)
         return ret
 
     def __fetchCitationReferenceProvider(self, cfgOb, configName, cachePath, useCache=True, **kwargs):
@@ -233,8 +242,9 @@ class DictMethodResourceProvider(SingletonClass):
     def __fetchValidationProvider(self, cfgOb, configName, cachePath, useCache=True, **kwargs):
         logger.debug("configName %s cachePath %s kwargs %r", configName, cachePath, kwargs)
         if not self.__vrptP:
+            urlTarget = cfgOb.get("VRPT_DICT_MAPPING_LOCATOR", sectionName=configName)
             dirPath = os.path.join(cachePath, cfgOb.get("DICTIONARY_CACHE_DIR", sectionName=configName))
-            self.__vrptP = ValidationReportProvider(dirPath=dirPath, useCache=useCache)
+            self.__vrptP = ValidationReportProvider(dirPath=dirPath, urlTarget=urlTarget, useCache=useCache)
         #
         return self.__vrptP
 
