@@ -278,15 +278,37 @@ class DocumentDefinitionHelper(object):
                         # if tD["SEARCH_TYPE"] in ["exact-match", "suggest"]:
                         #    aD.setdefault((ff[0], ff[1]), []).append("full-text")
                     #
+                # REMOVE tmp print unique text search
+                # logger.info("%s:", collectionName)
+                # logger.info("- SEARCH_TYPE: text-mode")
+                # logger.info("  ATTRIBUTE_NAMES:")
+                # for tup, sL in aD.items():
+                #     if ("exact-match" in sL and "full-text" in sL) or ("default-match" in sL) or ("suggest" in sL and "exact-match" in sL and "full-text" in sL):
+                #         continue
+                #     if "full-text" in sL:
+                #         logger.info(" - %s.%s", tup[0], tup[1])
+                # #
                 cD[collectionName] = {tup: self.__filterSearchContexts(sorted(list(set(sL)))) for tup, sL in aD.items()}
             # logger.info("processed search context for %r", cD)
         except Exception as e:
             logger.exception("Failing with %s", str(e))
         return cD
 
-    def __filterSearchContexts(self, stL):
-        if "exact-match" in stL and "full-text" in stL:
-            stL.remove("full-text")
+    def __filterSearchContexts(self, stL, overlapFlag=False):
+        """Automatically filter dependent search contexts.
+
+        Leaving this in for now with a disable flab
+
+        Args:
+            stL (list): list of search context names
+            overlapFlag (bool, optional): disable flag to filter for overlapping search contexts. Defaults to False.
+
+        Returns:
+            [type]: [description]
+        """
+        if overlapFlag:
+            if "exact-match" in stL and "full-text" in stL:
+                stL.remove("full-text")
         return stL
 
     def getAttributeSearchContexts(self, collectionName, categoryName, attributeName):
@@ -345,24 +367,31 @@ class DocumentDefinitionHelper(object):
             logger.debug("CategoryName %r attributeName %r failing  %s", categoryName, attributeName, str(e))
         return ret
 
+    #
     def __prepareCategoryNested(self):
         """
         Example:
 
-            collection_category_nested:
-                pdbx_core_entry:
-                    - citation
-                pdbx_core_entity:
-                    - rcsb_polymer_entity_feature
-                pdbx_core_entity_instance:
-                    - rcsb_polymer_instance_feature
-
+        collection_category_nested:
+            pdbx_core_entry:
+              - CATEGORY: citation
+                NAME: citation_primary
+                CONTEXT_ATTRIBUTE_NAMES:
+                - citation.rcsb_is_primary
         """
         cD = {}
-        # preprocess the nesting data --
-        for collectionName, catNameL in self.__cfgD["collection_category_nested"].items():
-            catD = {catName: True for catName in catNameL}
-            cD[collectionName] = catD
+        try:
+            # preprocess the nesting data --
+            for collectionName, nDL in self.__cfgD["collection_category_nested"].items():
+                catD = {}
+                for nD in nDL:
+                    if "CONTEXT_ATTRIBUTE_NAMES" in nD and "NAME" in nD:
+                        catD[nD["CATEGORY"]] = {"CONTEXT_NAME": nD["NAME"], "CONTEXT_PATHS": nD["CONTEXT_ATTRIBUTE_NAMES"], "FIRST_CONTEXT_PATH": nD["CONTEXT_ATTRIBUTE_NAMES"][0]}
+                    elif "NAME" in nD:
+                        catD[nD["CATEGORY"]] = {"CONTEXT_NAME": nD["NAME"], "CONTEXT_PATHS": [], "FIRST_CONTEXT_PATH": None}
+                cD[collectionName] = catD
+        except Exception as e:
+            logger.exception("Failing with %s", str(e))
         return cD
 
     def isCategoryNested(self, collectionName, categoryName):
@@ -384,27 +413,60 @@ class DocumentDefinitionHelper(object):
             pass
         return ret
 
+    def getCategoryNestedContext(self, collectionName, categoryName):
+        """Return is the input category in this collection is nested.
+
+        Args:
+            collectionName (str): collection name
+            categoryName (str): category name
+
+        Returns:
+            dict: {"CONTEXT_NAME": <name>, "CONTEXT_PATHS": <full_path_list>}
+
+        """
+        ret = {}
+        try:
+            self.__categoryNested = self.__prepareCategoryNested() if not self.__categoryNested else self.__categoryNested
+            ret = self.__categoryNested[collectionName][categoryName]
+        except Exception:
+            pass
+        return ret
+
     def __prepareSubCategoryNested(self):
         """
         Example:
+        #
+        collection_subcategory_nested:
+            bird_chem_comp_core:
+                - CATEGORY: rcsb_chem_comp_related
+                  SUBCATEGORY: resource_lineage
+                  CONTEXT_ATTRIBUTE_NAMES:
+                  - rcsb_chem_comp_related.resource_lineage_depth
+            pdbx_core_polymer_entity:
+                - CATEGORY: rcsb_polymer_entity
+                  SUBCATEGORY: rcsb_ec_lineage
+                - CATEGORY: rcsb_polymer_entity
+                  SUBCATEGORY: rcsb_enzyme_class_combined
 
-            collection_subcategory_nested:
-                pdbx_core_entity:
-                    - ec_lineage
-                    - taxonomy_lineage
         """
         cD = {}
         # preprocess the nesting data --
-        for collectionName, subCatNameL in self.__cfgD["collection_subcategory_nested"].items():
-            subCatD = {subCatName: True for subCatName in subCatNameL}
+        for collectionName, nDL in self.__cfgD["collection_subcategory_nested"].items():
+            subCatD = {}
+            for nD in nDL:
+                if "CONTEXT_ATTRIBUTE_NAMES" in nD:
+                    subCatD[(nD["CATEGORY"], nD["SUBCATEGORY"])] = {"CONTEXT_NAME": nD["SUBCATEGORY"], "CONTEXT_PATHS": nD["CONTEXT_ATTRIBUTE_NAMES"]}
+                else:
+                    subCatD[(nD["CATEGORY"], nD["SUBCATEGORY"])] = {"CONTEXT_NAME": nD["SUBCATEGORY"]}
             cD[collectionName] = subCatD
         return cD
 
-    def isSubCategoryNested(self, collectionName, subCategoryName):
+    def isSubCategoryNested(self, collectionName, categoryName, subCategoryName):
         """Return is the input subcategory in this collection is nested.
 
         Args:
             collectionName (str): collection name
+            categoryName (str): category name
             subCategoryName (str): subcategory name
 
         Returns:
@@ -414,7 +476,27 @@ class DocumentDefinitionHelper(object):
         ret = False
         try:
             self.__subCategoryNested = self.__prepareSubCategoryNested() if not self.__subCategoryNested else self.__subCategoryNested
-            ret = subCategoryName in self.__subCategoryNested[collectionName]
+            ret = (categoryName, subCategoryName) in self.__subCategoryNested[collectionName]
+        except Exception:
+            pass
+        return ret
+
+    def getSubCategoryNestedContext(self, collectionName, categoryName, subCategoryName):
+        """Return is the input subcategory in this collection is nested.
+
+        Args:
+            collectionName (str): collection name
+            categoryName (str): categoryName
+            subCategoryName (str): subcategory name
+
+        Returns:
+            (dict): {"CONTEXT_NAME": <name>, "CONTEXT_PATHS": <full_path_list>}
+
+        """
+        ret = False
+        try:
+            self.__subCategoryNested = self.__prepareSubCategoryNested() if not self.__subCategoryNested else self.__subCategoryNested
+            ret = self.__subCategoryNested[collectionName][(categoryName, subCategoryName)]
         except Exception:
             pass
         return ret
