@@ -32,10 +32,14 @@ class SliceValues(object):
         self.__sD = schemaDefObj
         spiL = self.__sD.getSliceParentItems(sliceFilter)
         spfL = self.__sD.getSliceParentFilters(sliceFilter)
+        for sp in spiL:
+            catId = sp["CATEGORY"]
+            if catId not in schemaDataDictById:
+                logger.warning("slicefilter %s category missing %s keys %r", sliceFilter, catId, list(schemaDataDictById.keys()))
         vD = {}
         for sp in spiL:
-            catId = sp['CATEGORY']
-            atId = sp['ATTRIBUTE']
+            catId = sp["CATEGORY"]
+            atId = sp["ATTRIBUTE"]
             vals = []
             if catId in schemaDataDictById:
                 for rowD in schemaDataDictById[catId]:
@@ -44,25 +48,25 @@ class SliceValues(object):
             vD[(catId, atId)] = vals
         #
         self.index = 0
-        logger.debug("Parent value dict %r" % vD.items())
+        logger.debug("Filter %r parent value dict %r", sliceFilter, vD.items())
         # Make a list of lists and then get the product
         #
         valueL = []
-        for ky, vL in vD.items():
+        for _, vL in vD.items():
             valueL.append(vL)
         self.data = list(itertools.product(*valueL))
-        logger.debug("Parent value product list %r" % self.data)
+        logger.debug("Filter %r parent value product list %r", sliceFilter, self.data)
 
     def isEmpty(self):
         return len(self.data) < 1
 
     def __testFilter(self, rowD, catId, filters):
         ok = True
-        for filter in filters:
-            if catId != filter['CATEGORY']:
+        for flt in filters:
+            if catId != flt["CATEGORY"]:
                 ok = False
                 break
-            if filter['ATTRIBUTE'] in rowD and rowD[filter['ATTRIBUTE']] in filter['VALUES']:
+            if flt["ATTRIBUTE"] in rowD and rowD[flt["ATTRIBUTE"]] in flt["VALUES"]:
                 continue
             else:
                 ok = False
@@ -103,19 +107,19 @@ class SchemaDefReShape(object):
         self.__sD = schemaDefAccessObj
         #
 
-    def applyShape(self, schemaDataDictById, styleType="rowwise_by_name"):
+    def applyShape(self, schemaDataDictById, styleType="rowwise_by_name", collectionName=None):
         """
         """
-        return self.__reshapeSchemaData(schemaDataDictById, styleType=styleType)
+        return self.__reshapeSchemaData(schemaDataDictById, styleType=styleType, collectionName=collectionName)
 
-    def applySlicedShape(self, schemaDataDictById, styleType="rowwise_by_name", logSize=False, sliceFilter=None):
+    def applySlicedShape(self, schemaDataDictById, styleType="rowwise_by_name", sliceFilter=None, collectionName=None):
         """
         """
         rL = []
         if sliceFilter:
             rL = []
             sliceIndex = self.__sD.getSliceIndex(sliceFilter)
-            logger.debug("Slice index %r" % sliceIndex)
+            logger.debug("Slice index %r", sliceIndex)
             #
             #
             sliceValues = SliceValues(schemaDataDictById, self.__sD, sliceFilter)
@@ -125,22 +129,22 @@ class SchemaDefReShape(object):
             flagNew = True
             # JDW - This path is better performing -
             if styleType == "rowwise_by_name_with_cardinality" and flagNew:
-                logger.debug("Invoking one-pass slice filter %s" % sliceFilter)
-                rL = self.__sliceRowwiseByNameWithCardOnePass(schemaDataDictById, sliceFilter, sliceIndex)
-                logger.debug("Completed one-pass slice filter %s" % sliceFilter)
+                logger.debug("Invoking one-pass slice filter %s", sliceFilter)
+                rL = self.__sliceRowwiseByNameWithCardOnePass(schemaDataDictById, sliceFilter, sliceIndex, collectionName=collectionName)
+                logger.debug("Completed one-pass slice filter %s", sliceFilter)
             else:
                 # JDW - This path works but is not well performing
                 for ii, sliceValue in enumerate(sliceValues):
-                    logger.debug(" %4d filter %s slice value %r" % (ii, sliceFilter, sliceValue))
-                    rD = self.__reshapeSlicedSchemaData(schemaDataDictById, sliceFilter, sliceValue, sliceIndex, styleType=styleType)
-                    logger.debug("rD keys %s" % (rD.keys()))
+                    logger.debug(" %4d filter %s slice value %r", ii, sliceFilter, sliceValue)
+                    rD = self.__reshapeSlicedSchemaData(schemaDataDictById, sliceFilter, sliceValue, sliceIndex, styleType=styleType, collectionName=collectionName)
+                    logger.debug("rD keys %s", rD.keys())
                     rL.append(rD)
         else:
-            return [self.__reshapeSchemaData(schemaDataDictById, styleType=styleType)]
+            return [self.__reshapeSchemaData(schemaDataDictById, styleType=styleType, collectionName=collectionName)]
 
         return rL
 
-    def __reshapeSlicedSchemaData(self, schemaDataDictById, sliceFilter, sliceValues, sliceIndex, styleType="rowwise_by_name"):
+    def __reshapeSlicedSchemaData(self, schemaDataDictById, sliceFilter, sliceValues, sliceIndex, styleType="rowwise_by_name", collectionName=None):
         """  Reorganize and rename input table data object according to the input style preference:
 
              Input: schemaDataDictById  (styleType="rowwise_by_id")
@@ -155,20 +159,20 @@ class SchemaDefReShape(object):
         rD = {}
         try:
             if styleType == "rowwise_by_name":
-                rD = self.__sliceRowwiseByName(schemaDataDictById, sliceFilter, sliceValues, sliceIndex)
+                rD = self.__sliceRowwiseByName(schemaDataDictById, sliceFilter, sliceValues, sliceIndex, collectionName=collectionName)
             elif styleType == "rowwise_by_name_with_cardinality":
-                rD = self.__sliceRowwiseByNameWithCard(schemaDataDictById, sliceFilter, sliceValues, sliceIndex)
+                rD = self.__sliceRowwiseByNameWithCard(schemaDataDictById, sliceFilter, sliceValues, sliceIndex, collectionName=collectionName)
             elif styleType == "columnwise_by_name":
-                rD = self.__sliceColumnwise(schemaDataDictById, sliceFilter, sliceValues, sliceIndex)
+                rD = self.__sliceColumnwise(schemaDataDictById, sliceFilter, sliceValues, sliceIndex, collectionName=collectionName)
             elif styleType == "rowwise_no_name":
                 rD = self.__shapeRowwiseNoName(schemaDataDictById)
             elif styleType == "rowwise_by_id":
                 rD = schemaDataDictById
             else:
                 rD = schemaDataDictById
-                logger.warning("Unsupported style type %s" % styleType)
+                logger.warning("Unsupported style type %s", styleType)
         except Exception as e:
-            logger.exception("Failing with %s" % str(e))
+            logger.exception("Failing with %s", str(e))
             rD = schemaDataDictById
 
         return rD
@@ -199,17 +203,18 @@ class SchemaDefReShape(object):
                 ok = False
 
         except Exception as e:
-            logger.exception("Failing with %s" % str(e))
+            logger.exception("Failing with %s", str(e))
             ok = False
         return ok
 
-    def __sliceRowwiseByNameWithCard(self, schemaDataDictById, sliceFilter, sliceValues, sliceIndex):
+    def __sliceRowwiseByNameWithCard(self, schemaDataDictById, sliceFilter, sliceValues, sliceIndex, collectionName=None):
         rD = {}
+        attributeExcludeD = self.__sD.getCollectionExcludedAttributes(collectionName, asSchemaIds=True)
         for schemaId in schemaDataDictById:
             schemaObj = self.__sD.getSchemaObject(schemaId)
             lExtra = schemaObj.isSliceExtra(sliceFilter)
             if lExtra:
-                logger.debug("SchemaId %r slice extra %r" % (schemaId, lExtra))
+                logger.debug("SchemaId %r slice extra %r", schemaId, lExtra)
             if schemaId not in sliceIndex and not schemaObj.isSliceExtra(sliceFilter):
                 continue
             # ------
@@ -223,11 +228,13 @@ class SchemaDefReShape(object):
                 if lExtra or self.__inSlice(schemaId, sliceIndex, iRowD, sliceValues):
                     oRowD = {}
                     for atId in iRowD:
+                        if (schemaId, atId) in attributeExcludeD:
+                            continue
                         oRowD[schemaObj.getAttributeName(atId)] = iRowD[atId]
                     oRowDList.append(oRowD)
 
-            if (len(oRowDList) < 1) and not schemaObj.isMandatory():
-                logger.debug("Schema id %r row length %r mandatory %r" % (schemaId, len(oRowDList), schemaObj.isMandatory()))
+            if not oRowDList and not schemaObj.isMandatory():
+                logger.debug("Schema id %r row length %r mandatory %r", schemaId, len(oRowDList), schemaObj.isMandatory())
                 continue
 
             if schemaObj.hasSliceUnitCardinality(sliceFilter) and len(oRowDList) == 1:
@@ -237,13 +244,14 @@ class SchemaDefReShape(object):
 
         return rD
 
-    def __sliceRowwiseByName(self, schemaDataDictById, sliceFilter, sliceValues, sliceIndex):
+    def __sliceRowwiseByName(self, schemaDataDictById, sliceFilter, sliceValues, sliceIndex, collectionName=None):
         rD = {}
+        attributeExcludeD = self.__sD.getCollectionExcludedAttributes(collectionName, asSchemaIds=True)
         for schemaId in schemaDataDictById:
             schemaObj = self.__sD.getSchemaObject(schemaId)
             lExtra = schemaObj.isSliceExtra(sliceFilter)
             if lExtra:
-                logger.debug("SchemaId %r slice extra %r" % (schemaId, lExtra))
+                logger.debug("SchemaId %r slice extra %r", schemaId, lExtra)
             if schemaId not in sliceIndex and not schemaObj.isSliceExtra(sliceFilter):
                 continue
             # ------
@@ -256,23 +264,26 @@ class SchemaDefReShape(object):
                 if lExtra or self.__inSlice(schemaId, sliceIndex, iRowD, sliceValues):
                     oRowD = {}
                     for atId in iRowD:
+                        if (schemaId, atId) in attributeExcludeD:
+                            continue
                         oRowD[schemaObj.getAttributeName(atId)] = iRowD[atId]
                     oRowDList.append(oRowD)
             #
-            if (len(oRowDList) < 1) and not schemaObj.isMandatory():
-                logger.debug("Schema id %r row length %r mandatory %r" % (schemaId, len(oRowDList), schemaObj.isMandatory()))
+            if not oRowDList and not schemaObj.isMandatory():
+                logger.debug("Schema id %r row length %r mandatory %r", schemaId, len(oRowDList), schemaObj.isMandatory())
                 continue
             rD[schemaObjName] = oRowDList
 
         return rD
 
-    def __sliceColumnwise(self, schemaDataDictById, sliceFilter, sliceValues, sliceIndex):
+    def __sliceColumnwise(self, schemaDataDictById, sliceFilter, sliceValues, sliceIndex, collectionName=None):
         rD = {}
+        attributeExcludeD = self.__sD.getCollectionExcludedAttributes(collectionName, asSchemaIds=True)
         for schemaId in schemaDataDictById:
             schemaObj = self.__sD.getSchemaObject(schemaId)
             lExtra = schemaObj.isSliceExtra(sliceFilter)
             if lExtra:
-                logger.debug("SchemaId %r slice extra %r" % (schemaId, lExtra))
+                logger.debug("SchemaId %r slice extra %r", schemaId, lExtra)
             if schemaId not in sliceIndex and not schemaObj.isSliceExtra(sliceFilter):
                 continue
             # ------
@@ -283,13 +294,15 @@ class SchemaDefReShape(object):
             for iRowD in iRowDList:
                 if lExtra or self.__inSlice(schemaId, sliceIndex, iRowD, sliceValues):
                     for atId in iRowD:
+                        if (schemaId, atId) in attributeExcludeD:
+                            continue
                         atName = schemaObj.getAttributeName(atId)
                         if atName not in colD:
                             colD[atName] = []
                         colD[atName].append(iRowD[atId])
 
-            if (len(colD) < 1) and not schemaObj.isMandatory():
-                logger.debug("Schema id %r row length %r mandatory %r" % (schemaId, len(colD), schemaObj.isMandatory()))
+            if not colD and not schemaObj.isMandatory():
+                logger.debug("Schema id %r row length %r mandatory %r", schemaId, len(colD), schemaObj.isMandatory())
                 continue
             rD[schemaObjName] = colD
 
@@ -301,7 +314,7 @@ class SchemaDefReShape(object):
             schemaObj = self.__sD.getSchemaObject(schemaId)
             lExtra = schemaObj.isSliceExtra(sliceFilter)
             if lExtra:
-                logger.debug("SchemaId %r slice extra %r" % (schemaId, lExtra))
+                logger.debug("SchemaId %r slice extra %r", schemaId, lExtra)
             if schemaId not in sliceIndex and not schemaObj.isSliceExtra(sliceFilter):
                 continue
             # ------
@@ -317,17 +330,19 @@ class SchemaDefReShape(object):
                 if lExtra or self.__inSlice(schemaId, sliceIndex, iRowD, sliceValues):
                     oRowL = []
                     for atId in atIdList:
-                        oRowL.append(iRowD[atId])
+                        rVal = iRowD[atId] if atId in iRowD else None
+                        oRowL.append(rVal)
                     oRowList.append(oRowL)
             #
-            if (len(oRowList) < 1) and not schemaObj.isMandatory():
-                logger.debug("Schema id %r row length %r mandatory %r" % (schemaId, len(oRowList), schemaObj.isMandatory()))
+            if not oRowList and not schemaObj.isMandatory():
+                logger.debug("Schema id %r row length %r mandatory %r", schemaId, len(oRowList), schemaObj.isMandatory())
                 continue
-            rD[schemaObjName] = {'attributes': atNameList, 'data': oRowList}
+            rD[schemaObjName] = {"attributes": atNameList, "data": oRowList}
 
         return rD
 
-    def __reshapeSchemaData(self, schemaDataDictById, styleType="rowwise_by_name"):
+    #
+    def __reshapeSchemaData(self, schemaDataDictById, styleType="rowwise_by_name", collectionName=None):
         """  Reorganize and rename input table data object according to the input style preference:
 
              Input: schemaDataDictById  (styleType="rowwise_by_id")
@@ -342,26 +357,27 @@ class SchemaDefReShape(object):
         rD = {}
         try:
             if styleType == "rowwise_by_name":
-                rD = self.__shapeRowwiseByName(schemaDataDictById)
+                rD = self.__shapeRowwiseByName(schemaDataDictById, collectionName=collectionName)
             elif styleType == "rowwise_by_name_with_cardinality":
-                rD = self.__shapeRowwiseByNameWithCard(schemaDataDictById)
+                rD = self.__shapeRowwiseByNameWithCard(schemaDataDictById, collectionName=collectionName)
             elif styleType == "columnwise_by_name":
-                rD = self.__shapeColumnwise(schemaDataDictById)
+                rD = self.__shapeColumnwise(schemaDataDictById, collectionName=collectionName)
             elif styleType == "rowwise_no_name":
                 rD = self.__shapeRowwiseNoName(schemaDataDictById)
             elif styleType == "rowwise_by_id":
                 rD = schemaDataDictById
             else:
                 rD = schemaDataDictById
-                logger.warning("Unsupported style type %s" % styleType)
+                logger.warning("Unsupported style type %s", styleType)
         except Exception as e:
-            logger.exception("Failing with %s" % str(e))
+            logger.exception("Failing with %s", str(e))
             rD = schemaDataDictById
 
         return rD
 
-    def __shapeRowwiseByName(self, schemaDataDictById):
+    def __shapeRowwiseByName(self, schemaDataDictById, collectionName=None):
         rD = {}
+        attributeExcludeD = self.__sD.getCollectionExcludedAttributes(collectionName, asSchemaIds=True)
         for schemaId in schemaDataDictById:
             schemaObj = self.__sD.getSchemaObject(schemaId)
             schemaObjName = self.__sD.getSchemaName(schemaId)
@@ -370,13 +386,16 @@ class SchemaDefReShape(object):
             for iRowD in iRowDList:
                 oRowD = {}
                 for atId in iRowD:
+                    if (schemaId, atId) in attributeExcludeD:
+                        continue
                     oRowD[schemaObj.getAttributeName(atId)] = iRowD[atId]
                 oRowDList.append(oRowD)
             rD[schemaObjName] = oRowDList
         return rD
 
-    def __shapeRowwiseByNameWithCard(self, schemaDataDictById):
+    def __shapeRowwiseByNameWithCard(self, schemaDataDictById, collectionName=None):
         rD = {}
+        attributeExcludeD = self.__sD.getCollectionExcludedAttributes(collectionName, asSchemaIds=True)
         for schemaId in schemaDataDictById:
             schemaObj = self.__sD.getSchemaObject(schemaId)
             schemaObjName = self.__sD.getSchemaName(schemaId)
@@ -387,6 +406,8 @@ class SchemaDefReShape(object):
                 iRowD = iRowDList[0]
                 oRowD = {}
                 for atId in iRowD:
+                    if (schemaId, atId) in attributeExcludeD:
+                        continue
                     oRowD[schemaObj.getAttributeName(atId)] = iRowD[atId]
                 rD[schemaObjName] = oRowD
             else:
@@ -394,13 +415,16 @@ class SchemaDefReShape(object):
                 for iRowD in iRowDList:
                     oRowD = {}
                     for atId in iRowD:
+                        if (schemaId, atId) in attributeExcludeD:
+                            continue
                         oRowD[schemaObj.getAttributeName(atId)] = iRowD[atId]
                     oRowDList.append(oRowD)
                 rD[schemaObjName] = oRowDList
         return rD
 
-    def __shapeColumnwise(self, schemaDataDictById):
+    def __shapeColumnwise(self, schemaDataDictById, collectionName=None):
         rD = {}
+        attributeExcludeD = self.__sD.getCollectionExcludedAttributes(collectionName, asSchemaIds=True)
         for schemaId in schemaDataDictById:
             schemaObj = self.__sD.getSchemaObject(schemaId)
             schemaObjName = self.__sD.getSchemaName(schemaId)
@@ -408,6 +432,8 @@ class SchemaDefReShape(object):
             colD = {}
             for iRowD in iRowDList:
                 for atId in iRowD:
+                    if (schemaId, atId) in attributeExcludeD:
+                        continue
                     atName = schemaObj.getAttributeName(atId)
                     if atName not in colD:
                         colD[atName] = []
@@ -428,24 +454,26 @@ class SchemaDefReShape(object):
             for iRowD in iRowDList:
                 oRowL = []
                 for atId in atIdList:
-                    oRowL.append(iRowD[atId])
+                    rVal = iRowD[atId] if atId in iRowD else None
+                    oRowL.append(rVal)
                 oRowList.append(oRowL)
             #
-            rD[schemaObjName] = {'attributes': atNameList, 'data': oRowList}
+            rD[schemaObjName] = {"attributes": atNameList, "data": oRowList}
         return rD
 
     # ---------------------- ---------------------- ---------------------- ---------------------- ----------------------
     #
-    def __sliceRowwiseByNameWithCardOnePass(self, schemaDataDictById, sliceFilter, sliceIndex):
-
+    def __sliceRowwiseByNameWithCardOnePass(self, schemaDataDictById, sliceFilter, sliceIndex, collectionName=None):
+        debug = False
         #
+        attributeExcludeD = self.__sD.getCollectionExcludedAttributes(collectionName, asSchemaIds=True)
         schemaIdExtraL = self.__sD.getSliceExtraSchemaIds(sliceFilter)
-        #logger.info("Schema Id extras %r" % schemaIdExtraL)
+        # logger.info("Schema Id extras %r" % schemaIdExtraL)
         #
         for schemaId in schemaDataDictById:
             # sliceIndex = {'schemaId0': {(pCat0,pAt0): chAt0,  (pCat1,pAt1): chAt1}, ... }, ... }
             if schemaId in sliceIndex:
-                logger.debug("SLICE %s - schemaId %s -> %r" % (sliceFilter, schemaId, sliceIndex[schemaId]))
+                logger.debug("SLICE %s - schemaId %s -> %r", sliceFilter, schemaId, sliceIndex[schemaId])
         #
         # Build  value -> parent attributes dictionary -
         #
@@ -474,7 +502,7 @@ class SchemaDefReShape(object):
         # Each parent key in the slice filter -
         ##
         for pvTup in pvTupL:
-            logger.debug("VALUES > Slice filter %s parent %r value %r" % (sliceFilter, pvTup[0], pvTup[1]))
+            logger.debug("VALUES > Slice filter %s parent %r value %r", sliceFilter, pvTup[0], pvTup[1])
             # sliceIndex = {'schemaId0': mD, ... }
             #         mD = {(pCat0,pAt0): chAt0,  (pCat1,pAt1): chAt1}, ... }, ... }
             for schemaId, mD in sliceIndex.items():
@@ -483,8 +511,8 @@ class SchemaDefReShape(object):
                     sfAtD[schemaId].setdefault(pvTup[0], []).extend([k for k in mD[pvTup[0]]])
                     singleKeyAtD.setdefault(schemaId, []).extend([k for k in mD[pvTup[0]]])
                 if len(sfAtD[schemaId]) > 1:
-                    logger.error("Unsupported slice complexity %s key length %d" % (sliceFilter, len(sfAtD[schemaId])))
-        logger.debug("Ordered slice filter attribute dictionary %r" % singleKeyAtD)
+                    logger.error("Unsupported slice complexity %s key length %d", sliceFilter, len(sfAtD[schemaId]))
+        logger.debug("Ordered slice filter attribute dictionary %r", singleKeyAtD)
         #
         # Slice extra objects get replicated in each slice -
         #
@@ -502,8 +530,8 @@ class SchemaDefReShape(object):
                         oRowD[schemaObj.getAttributeName(atId)] = iRowD[atId]
                     oRowDList.append(oRowD)
 
-                if (len(oRowDList) < 1) and not schemaObj.isMandatory():
-                    logger.debug("Schema id %r row length %r mandatory %r" % (schemaId, len(oRowDList), schemaObj.isMandatory()))
+                if not oRowDList and not schemaObj.isMandatory():
+                    logger.debug("Schema id %r row length %r mandatory %r", schemaId, len(oRowDList), schemaObj.isMandatory())
                     continue
 
                 if schemaObj.hasSliceUnitCardinality(sliceFilter) and len(oRowDList) == 1:
@@ -513,15 +541,18 @@ class SchemaDefReShape(object):
             for pv in pVals:
                 retD[pv] = copy.copy(rD)
         #
-        #logger.info("slice %s retD keys after slice extra insertion %r" % (sliceFilter, list(retD.keys())))
-        # logger.info("slice %s retD after slice extra insertion %r" % (sliceFilter, retD))
+        # logger.info("slice %s retD keys after slice extra insertion %r", sliceFilter, list(retD.keys()))
+        # logger.info("slice %s retD after slice extra insertion %r", sliceFilter, retD)
 
         #
         # Split of the rest by slice value - for single parent key slices  -
         #
-        #logger.info("slice %s singleKeyAtD.keys() %r" % (sliceFilter, list(singleKeyAtD.keys())))
+        # logger.info("slice %s singleKeyAtD.keys() %r", sliceFilter, list(singleKeyAtD.keys()))
         #
         for schemaId, atL in singleKeyAtD.items():
+            #
+            # apply collection exclusion filter
+            # atL = [atId for atId in atFullL if (schemaId, atId) not in attributeExcludeD]
             #
             schemaObj = self.__sD.getSchemaObject(schemaId)
             # ------
@@ -531,27 +562,35 @@ class SchemaDefReShape(object):
             #
             iRowDList = schemaDataDictById[schemaId]
             rvS = set()
+            # logger.info("collectionName %s attributeExcludeD %r", collectionName, attributeExcludeD)
             for iRowD in iRowDList:
-                oRowD = {schemaObj.getAttributeName(atId): iRowD[atId] for atId in iRowD}
-                #
+                # Add collection exclusion filter here
+                oRowD = {schemaObj.getAttributeName(atId): iRowD[atId] for atId in iRowD if (schemaId, atId) not in attributeExcludeD}
+                # JDW skip empty rows -
+                if not oRowD:
+                    continue
                 rvS = set([iRowD[at] if at in iRowD else None for at in atL])
                 for rv in rvS:
-                    #logger.info("Slice %s schemaId %s uFlag %r value %r ADD ROW %r" % (sliceFilter, schemaObjName, uFlag, rv, oRowD))
-                    if rv:
-                        #
+                    # if rv is null or has no parent then the following will fail -
+                    # JDW CHANGE - Use a try rather than 'if'   Ignorring error for now
+                    try:
                         if uFlag:
                             retD[rv][schemaObjName] = oRowD
                         else:
                             retD[rv].setdefault(schemaObjName, []).append(oRowD)
+                    except Exception:
+                        pass
+
             #
-            #logger.info("Slice %s Finished loading schema name %s values %r" % (sliceFilter, schemaObjName, rvS))
+            # logger.info("Slice %s Finished loading schema name %s values %r" % (sliceFilter, schemaObjName, rvS))
             #
+
             #
-            if False:
+            if debug:
                 for pv in retD:
                     if schemaObjName in retD[pv]:
                         logger.info(">>>>>>>>")
-                        logger.info("slice %s schemaObjName %s value %r obj %r" % (sliceFilter, schemaObjName, pv, retD[pv][schemaObjName]))
+                        logger.info("slice %s schemaObjName %s value %r obj %r", sliceFilter, schemaObjName, pv, retD[pv][schemaObjName])
                         logger.info(">>>>>>>>")
         #
         return list(retD.values())
